#include "postgresql-libpq-6.2.x.hh"

#line 1 "test-iterators.uesql.cc"
//
//  Name:      test-iterators.uesql.cc
//  Author:    Francisco Vides Fernandez
//  Summary:   
//  Date:      $Date: 2001/02/15 17:04:30 $
//  Revision:  $Revision: 1.8 $
//
//  Copyright (C) 1999  Rafael Jesus Alcantara Perez <rafa@dedalo-ing.com>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
//  MA 02111-1307, USA.
//

#include <iostream>
#include <mpcl/config_processor.hh>
#include <mpcl/general-exceptions.hh>
#include <mpcl/string.hh>
#include <mpcl/test.h>
#include <uesql/iterator.hh>
#include <uesql/query.hh>


using uesql::TSqlDataType;
using uesql::TSqlDate;
using uesql::TSqlInteger;
using uesql::TSqlReal;
using uesql::TSqlString;
using uesql::TIterator;
using uesql::TExceptionUESQL_Sqlerror;
using uesql::TQuery;

//
// L O C A L  C L A S S E S
//

class TTestInstance
{
    
  public:

    TSqlDate     tAttrib0;
    TSqlInteger  tAttrib1;
    TSqlReal     tAttrib2;
    TSqlString   tAttrib3;

    
  public:

    TTestInstance()  :
      tAttrib0() ,
      tAttrib1() ,
      tAttrib2() ,
      tAttrib3() {};


  public: 

    TSqlDataType& operator [] (unsigned int uiI)
    {
      switch (uiI)
      {
        case 0:
        {
          return tAttrib0;
          break;
        }
        case 1:
        {
          return tAttrib1;
          break;
        }
        case 2:
        {
          return tAttrib2;
          break;
        }
        case 3:
        {
          return tAttrib3;
          break;
        }
        default:        
        {
          throw mpcl::TExceptionEL_Constraint ("index out of range", __FILE__, __LINE__);
        }
      }
      return tAttrib0; // never reached
    }

    
    bool operator == (const TTestInstance& rktINSTANCE) const
    {
      return 
        ( tAttrib0 == rktINSTANCE.tAttrib0 ) &&
        ( tAttrib1 == rktINSTANCE.tAttrib1 ) &&
        ( tAttrib2 == rktINSTANCE.tAttrib2 ) &&
        ( tAttrib3 == rktINSTANCE.tAttrib3 ) ;
    }
    

};  // class TTestInstance


ostream& operator << (ostream& rtOSTREAM, TTestInstance& rtINSTANCE)
{

  for (register unsigned int I = 0; I < 4 ; I++)
  {
    rtOSTREAM << rtINSTANCE [I].get() << endl;
  }
  return rtOSTREAM;

}  // operator <<()


struct MQuery
{

  protected:

    
    void declare (uesql::TSqlString yCURSOR_NAME, std::size_t* ptTUPLE_COUNT) const
    {
      TSqlInteger   iAux;
#line 138 "test-iterators.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 139 "test-iterators.uesql.cc"
{
PGresult*   ptPgresult;
int         hI = 0;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnOutputQueue (&iAux);

uesql::htPostgresql62xManager.begin();
ptPgresult = uesql::htPostgresql62xManager.execute ("DECLARE AUX_CURSOR CURSOR FOR SELECT COUNT (*) FROM INSTANCE;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( !uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  ptPgresult = uesql::htPostgresql62xManager.execute ("FETCH ALL IN AUX_CURSOR;");
  uesql::htPostgresql62xManager.diagnoseSingleRow (ptPgresult);
}
if ( uesql::htPostgresql62xManager.isNotFoundCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  uesql::htPostgresql62xManager.executeClean ("CLOSE AUX_CURSOR;");
  uesql::htPostgresql62xManager.end();
  
throw uesql::TExceptionUESQL_NotFound (__FILE__, __LINE__);
}
else if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  uesql::htPostgresql62xManager.executeClean ("CLOSE AUX_CURSOR;");
  uesql::htPostgresql62xManager.end();
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
else
{
#ifdef _UESQL_DEBUG__
  mpcl::log << mpcl::header << "SELECTED (";
#endif  // not _UESQL_DEBUG__
if ( PQgetisnull (ptPgresult, 0, hI) )
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (NULL);
  }
  else
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
  }
# ifdef _UESQL_DEBUG__
  mpcl::log << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
#ifdef _UESQL_DEBUG__
  mpcl::log << ");\n";
#endif  // not _UESQL_DEBUG__
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  uesql::htPostgresql62xManager.executeClean ("CLOSE AUX_CURSOR;");
  uesql::htPostgresql62xManager.end();
}
}
#line 142 "test-iterators.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnInputQueue (yCURSOR_NAME);

uesql::htPostgresql62xManager.begin();
ptPgresult = uesql::htPostgresql62xManager.execute ("DECLARE $z CURSOR FOR SELECT ATTRIB0, ATTRIB1, ATTRIB2, ATTRIB3 FROM INSTANCE;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 143 "test-iterators.uesql.cc"

      *ptTUPLE_COUNT = (size_t) iAux;
    }

    void fetchNext (const uesql::TSqlString& rkyCURSOR_NAME, TTestInstance& tINSTANCE)
    {
      TTestInstance tRet;
#line 151 "test-iterators.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 157 "test-iterators.uesql.cc"
{
PGresult*   ptPgresult;
int         hI = 0;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnInputQueue (rkyCURSOR_NAME);
uesql::htPostgresql62xManager.pushOnOutputQueue (&tINSTANCE.tAttrib0);
uesql::htPostgresql62xManager.pushOnOutputQueue (&tINSTANCE.tAttrib1);
uesql::htPostgresql62xManager.pushOnOutputQueue (&tINSTANCE.tAttrib2);
uesql::htPostgresql62xManager.pushOnOutputQueue (&tINSTANCE.tAttrib3);

ptPgresult = uesql::htPostgresql62xManager.execute ("FETCH IN $z;");
uesql::htPostgresql62xManager.diagnoseSingleRow (ptPgresult);
if ( uesql::htPostgresql62xManager.isNotFoundCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  
throw uesql::TExceptionUESQL_NotFound (__FILE__, __LINE__);
}
else if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
else
{
#ifdef _UESQL_DEBUG__
  mpcl::log << mpcl::header << "FETCHED (";
#endif  // not _UESQL_DEBUG__
if ( PQgetisnull (ptPgresult, 0, hI) )
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (NULL);
  }
  else
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
  }
# ifdef _UESQL_DEBUG__
  mpcl::log << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
  if ( PQgetisnull (ptPgresult, 0, hI) )
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (NULL);
  }
  else
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
  }
# ifdef _UESQL_DEBUG__
  mpcl::log << ", " << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
  if ( PQgetisnull (ptPgresult, 0, hI) )
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (NULL);
  }
  else
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
  }
# ifdef _UESQL_DEBUG__
  mpcl::log << ", " << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
  if ( PQgetisnull (ptPgresult, 0, hI) )
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (NULL);
  }
  else
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
  }
# ifdef _UESQL_DEBUG__
  mpcl::log << ", " << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
#ifdef _UESQL_DEBUG__
  mpcl::log << ");\n";
#endif  // not _UESQL_DEBUG__
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 158 "test-iterators.uesql.cc"

    }

    TTestInstance& fetchAbsolute ( uesql::TSqlString yCURSOR_NAME        ,
                                   TTestInstance& tINSTANCE              ,
                                   const uesql::TSqlInteger& rkiPOSITION )
    {
#line 166 "test-iterators.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 172 "test-iterators.uesql.cc"
{
PGresult*       ptPgresult;
mpcl::xstring   hySqlInstructionAux;
mpcl::xstring   hyCursorName = "$z";
int             hI           = 0;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnInputQueue (rkiPOSITION);
uesql::htPostgresql62xManager.pushOnInputQueue (yCURSOR_NAME);
uesql::htPostgresql62xManager.pushOnOutputQueue (&tINSTANCE.tAttrib0);
uesql::htPostgresql62xManager.pushOnOutputQueue (&tINSTANCE.tAttrib1);
uesql::htPostgresql62xManager.pushOnOutputQueue (&tINSTANCE.tAttrib2);
uesql::htPostgresql62xManager.pushOnOutputQueue (&tINSTANCE.tAttrib3);

{
PGresult*   ptPgresult;

ptPgresult = uesql::htPostgresql62xManager.execute (mpcl::Format ("MOVE BACKWARD ALL IN %s;", hyCursorName.c_str()));
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
if ( 0 != std::atoi (uesql::htPostgresql62xManager.instantiate ("$z").c_str()) )
{
  ptPgresult = uesql::htPostgresql62xManager.execute (mpcl::Format ("MOVE FORWARD $z IN %s;", hyCursorName.c_str()));
  uesql::htPostgresql62xManager.diagnose (ptPgresult);
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
  {
    
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
  }
}
}
ptPgresult = uesql::htPostgresql62xManager.execute ("FETCH IN $z;");
uesql::htPostgresql62xManager.diagnoseSingleRow (ptPgresult);
if ( uesql::htPostgresql62xManager.isNotFoundCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  
throw uesql::TExceptionUESQL_NotFound (__FILE__, __LINE__);
}
else if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
else
{
#ifdef _UESQL_DEBUG__
  mpcl::log << mpcl::header << "FETCHED (";
#endif  // not _UESQL_DEBUG__
if ( PQgetisnull (ptPgresult, 0, hI) )
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (NULL);
  }
  else
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
  }
# ifdef _UESQL_DEBUG__
  mpcl::log << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
  if ( PQgetisnull (ptPgresult, 0, hI) )
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (NULL);
  }
  else
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
  }
# ifdef _UESQL_DEBUG__
  mpcl::log << ", " << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
  if ( PQgetisnull (ptPgresult, 0, hI) )
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (NULL);
  }
  else
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
  }
# ifdef _UESQL_DEBUG__
  mpcl::log << ", " << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
  if ( PQgetisnull (ptPgresult, 0, hI) )
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (NULL);
  }
  else
  {
    uesql::htPostgresql62xManager.getFromOutputQueue (hI)->set (PQgetvalue (ptPgresult, 0, hI));
  }
# ifdef _UESQL_DEBUG__
  mpcl::log << ", " << uesql::htPostgresql62xManager.getFromOutputQueue (hI)->get();
# endif  // not _UESQL_DEBUG__
  ++hI;
#ifdef _UESQL_DEBUG__
  mpcl::log << ");\n";
#endif  // not _UESQL_DEBUG__
  uesql::htPostgresql62xManager.clearResult (ptPgresult);
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 173 "test-iterators.uesql.cc"

    }


};  // class struct MQuery


typedef uesql::TQuery<TTestInstance, MQuery>  TTestQuery;


//
//  L O C A L   V A R I A B L E S
//

static uesql::TSqlstateDescriptor   _tSqlstateDescriptor;


//
//  L O C A L   F U N C T I O N S
//

/**
*  Construct error message from SQL status.
*  @return SQL status message.
*/

static mpcl::xstring _GetErrorMessage (void)
{

  using mpcl::xstring;

  return ( xstring (_tSqlstateDescriptor.getClass())    +
           ": "                                         +
           xstring (_tSqlstateDescriptor.getSubclass()) +
           " (" + uesql::SQLMESSAGE + ")"               );

}  // _GetErrorMessage()


static void _CreateTestSchema ( const mpcl::xstring& rkyDBMS_SERVER_NAME ,
                                const mpcl::xstring& rkyUSER_NAME        ,
                                const mpcl::xstring& rkyUSER_PASSWORD    )
{

  using uesql::ComposeSchemaLocation;
  using uesql::ComposeUserLogin;
  using uesql::Quote;

  mpcl::xstring   yDbmsSchemaLocation     = ComposeSchemaLocation ( rkyDBMS_SERVER_NAME ,
                                                                    rkyUSER_NAME        );
  mpcl::xstring   yDbmsTestSchemaLocation = ComposeSchemaLocation ( rkyDBMS_SERVER_NAME     ,
                                                                    "TEST_ITERATORS_SCHEMA" );
  mpcl::xstring   yDbmsUserLogin          = ComposeUserLogin (rkyUSER_NAME, rkyUSER_PASSWORD);

  TEST_WRITE_INFO ("DBMS-SCHEMA-LOCATION      = %s", yDbmsSchemaLocation.c_str());
  TEST_WRITE_INFO ("DBMS-USER-LOGIN           = %s", yDbmsUserLogin.c_str());
  TEST_WRITE_INFO ("DBMS-TEST-SCHEMA-LOCATION = %s", yDbmsTestSchemaLocation.c_str());
#line 231 "test-iterators.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 236 "test-iterators.uesql.cc"
{
mpcl::xstring   hySqlServerDescriptor;
mpcl::xstring   hySqlServerName;
mpcl::xstring   hyDatabaseName;
mpcl::xstring   hyConnectionName;
mpcl::xstring   hyUserLogin;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnInputQueue (Quote (yDbmsSchemaLocation));
uesql::htPostgresql62xManager.pushOnInputQueue (Quote (yDbmsUserLogin));

hySqlServerDescriptor = uesql::htPostgresql62xManager.instantiate ("$z");
hyConnectionName      = "DEFAULT";
hyUserLogin           = uesql::htPostgresql62xManager.instantiate ("$z");
hySqlServerDescriptor.suppress ('\'');
if ( hySqlServerDescriptor.find ('/') == mpcl::xstring::npos )
{
  hySqlServerName = hySqlServerDescriptor;
}
else
{
  hySqlServerName = hySqlServerDescriptor.substr (0, hySqlServerDescriptor.find ('/'));
  hyDatabaseName  = hySqlServerDescriptor.substr (hySqlServerDescriptor.find ('/') + 1);
}
if ( uesql::htPostgresql62xManager.isConnected (hyConnectionName) )
{
  uesql::htPostgresql62xManager.disconnect (hyConnectionName);
}
if ( uesql::htPostgresql62xManager.isConnected (hyConnectionName) )
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection name in use
  //
  uesql::SQLCODE    = -1;
  uesql::SQLMESSAGE = "";
  uesql::SQLSTATE   = "08002";
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
else
{
  if ( hyDatabaseName.empty() )
  {
    //
    //  If there is no PostgreSQL database then connect to 'template1'
    //  (that should always exists).
    //
    hyDatabaseName = "template1";
  }
  uesql::htPostgresql62xManager.connect ( hyConnectionName ,
                                     hySqlServerName  ,
                                     hyDatabaseName   ,
                                     hyUserLogin      );
  if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
  {
    
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
  }
  else
  {
    uesql::htPostgresql62xManager.setCurrentConnection (hyConnectionName);
  }
}
}
#line 247 "test-iterators.uesql.cc"
{
PGresult*       ptPgresult;
mpcl::xstring   hyConnectionName;
mpcl::xstring   hyLastConnectionName = uesql::htPostgresql62xManager.currentConnectionName();

uesql::htPostgresql62xManager.clearQueues();

hyConnectionName = uesql::htPostgresql62xManager.instantiate ("TEST_ITERATORS_SCHEMA");
hyConnectionName.lowercase();
ptPgresult = uesql::htPostgresql62xManager.execute (mpcl::Format ("CREATE DATABASE %s;", hyConnectionName.c_str()));
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
uesql::htPostgresql62xManager.connect (hyConnectionName, hyConnectionName);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
else
{
  uesql::htPostgresql62xManager.setCurrentConnection (hyConnectionName);
  
{
PGresult*   ptPgresult;

ptPgresult = uesql::htPostgresql62xManager.execute ("CREATE TABLE INSTANCE (ATTRIB0 DATE, ATTRIB1 INT4, ATTRIB2 FLOAT8, ATTRIB3 VARCHAR (20));");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
}
  uesql::htPostgresql62xManager.disconnectCurrent();
  uesql::htPostgresql62xManager.setCurrentConnection (hyLastConnectionName);
}
}
#line 253 "test-iterators.uesql.cc"
{
mpcl::xstring   hySqlServerDescriptor;
mpcl::xstring   hySqlServerName;
mpcl::xstring   hyDatabaseName;
mpcl::xstring   hyConnectionName;
mpcl::xstring   hyUserLogin;

uesql::htPostgresql62xManager.clearQueues();
uesql::htPostgresql62xManager.pushOnInputQueue (Quote (yDbmsTestSchemaLocation));
uesql::htPostgresql62xManager.pushOnInputQueue (Quote (yDbmsUserLogin));

hySqlServerDescriptor = uesql::htPostgresql62xManager.instantiate ("$z");
hyConnectionName      = uesql::htPostgresql62xManager.instantiate ("_'myconnection'");
hyUserLogin           = uesql::htPostgresql62xManager.instantiate ("$z");
hySqlServerDescriptor.suppress ('\'');
hyConnectionName.suppress ('\'');
if ( hySqlServerDescriptor.find ('/') == mpcl::xstring::npos )
{
  hySqlServerName = hySqlServerDescriptor;
}
else
{
  hySqlServerName = hySqlServerDescriptor.substr (0, hySqlServerDescriptor.find ('/'));
  hyDatabaseName  = hySqlServerDescriptor.substr (hySqlServerDescriptor.find ('/') + 1);
}
if ( uesql::htPostgresql62xManager.isConnected (hyConnectionName) )
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection name in use
  //
  uesql::SQLCODE    = -1;
  uesql::SQLMESSAGE = "";
  uesql::SQLSTATE   = "08002";
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
else
{
  if ( hyDatabaseName.empty() )
  {
    //
    //  If there is no PostgreSQL database then connect to 'template1'
    //  (that should always exists).
    //
    hyDatabaseName = "template1";
  }
  uesql::htPostgresql62xManager.connect ( hyConnectionName ,
                                     hySqlServerName  ,
                                     hyDatabaseName   ,
                                     hyUserLogin      );
  if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
  {
    
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
  }
  else
  {
    uesql::htPostgresql62xManager.setCurrentConnection (hyConnectionName);
  }
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 254 "test-iterators.uesql.cc"


}  // _CreateTestSchema()


static void _DropTestSchema (void)
{

#line 263 "test-iterators.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 267 "test-iterators.uesql.cc"
{
PGresult*   ptPgresult;

//
//  'CASCADE' has been omitted.
//
uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("DROP TABLE INSTANCE;");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
}
#line 268 "test-iterators.uesql.cc"
{
uesql::htPostgresql62xManager.clearQueues();

if ( uesql::htPostgresql62xManager.existsDefaultConnection() )
{
  uesql::htPostgresql62xManager.resetStatus();
  uesql::htPostgresql62xManager.disconnectCurrent();
}
else
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection does not exist
  //
  uesql::SQLCODE    = -1;
  uesql::SQLMESSAGE = "";
  uesql::SQLSTATE   = "08003";
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
}
#line 269 "test-iterators.uesql.cc"
{
mpcl::xstring   hyConnectionName;

uesql::htPostgresql62xManager.clearQueues();

hyConnectionName = uesql::htPostgresql62xManager.instantiate ("DEFAULT");
hyConnectionName.suppress ('\'');
uesql::htPostgresql62xManager.setCurrentConnection (hyConnectionName);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
}
#line 274 "test-iterators.uesql.cc"
{
PGresult*       ptPgresult;
mpcl::xstring   hySchemaName;

//
//  'CASCADE' has been omitted.
//
uesql::htPostgresql62xManager.clearQueues();

hySchemaName = "TEST_ITERATORS_SCHEMA";
hySchemaName.lowercase();
ptPgresult = uesql::htPostgresql62xManager.execute (mpcl::Format ("DROP DATABASE %s;", hySchemaName.c_str()));
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 275 "test-iterators.uesql.cc"


}   // _DropTestSchema()


static void _FillTables (void)
{

#line 284 "test-iterators.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 285 "test-iterators.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO INSTANCE VALUES ('20-12-2000', 0, 0.0, 'valor 0');");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
}
#line 286 "test-iterators.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO INSTANCE VALUES ('20-12-2001', 1, 1.1, 'valor 1');");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
}
#line 287 "test-iterators.uesql.cc"
{
PGresult*   ptPgresult;

uesql::htPostgresql62xManager.clearQueues();

ptPgresult = uesql::htPostgresql62xManager.execute ("INSERT INTO INSTANCE VALUES ('20-12-2002', 2, 2.2, 'valor 2');");
uesql::htPostgresql62xManager.diagnose (ptPgresult);
uesql::htPostgresql62xManager.clearResult (ptPgresult);
if ( uesql::htPostgresql62xManager.isSqlerrorCondition() )
{
  
throw uesql::TExceptionUESQL_Sqlerror (__FILE__, __LINE__);
}
}
}  // not PostgreSQL LIBPQ 6.2.x
#line 288 "test-iterators.uesql.cc"


}   // _FillTables()


static void _TestIteratorOperators (void)
{

  // Test ++I

  // Test I++

}   // _TestOperators()


int main (int argc, const char** argv)
{
  register int             I;
  mpcl::TConfigProcessor   tConfigProcessor (argc, argv);

  TEST_INIT ("Test for Cursor inside C++ Iterators");
  TEST_START_WATCH;
  try
  {
    tConfigProcessor.addOption ("dbms-server-name",   "o", getenv ("DBMS_SERVER_NAME"));
    tConfigProcessor.addOption ("dbms-user-name",     "u", getenv ("DBMS_USER_NAME"));
    tConfigProcessor.addOption ("dbms-user-password", "p", getenv ("DBMS_USER_NAME"));
    tConfigProcessor["dbms-server-name"].setUsageString ("Server where database resides");
    tConfigProcessor["dbms-user-name"].setUsageString ("");
    tConfigProcessor["dbms-user-password"].setUsageString ("");
    tConfigProcessor.processOptions();
    
    if ( !TEST_IN_SILENT_MODE )
    {
      mpcl::log.also (cerr);
    }
#line 325 "test-iterators.uesql.cc"
{
//
//  PostgreSQL LIBPQ 6.2.x instructions.
//
#line 329 "test-iterators.uesql.cc"

}  // not PostgreSQL LIBPQ 6.2.x
#line 331 "test-iterators.uesql.cc"

    _CreateTestSchema ( tConfigProcessor ["dbms-server-name"].value()   ,
                        tConfigProcessor ["dbms-user-name"].value()     ,
                        tConfigProcessor ["dbms-user-password"].value() );
    _FillTables();

    // <TODO comment="this will be the tests to run">
    _TestIteratorOperators ();
    // </TODO>    
    
    {
      // Iterate using a query
      TTestQuery             tTestQuery;
      TTestQuery::iterator   tTestIterator = tTestQuery.begin();

      // This one can test if an iterator's constructor returns a
      // valid one, being valid the data set
      if ( tTestIterator == tTestQuery.end() )
      {
        cout << "Alguna chorrada" << endl;
      }
      // Iterating a fixed number of times
      for (I = 0; I < 3 ;I++)
      {
        cout << *tTestIterator;
      }
      // Iterating through the container as usual
      tTestIterator = tTestQuery.begin();
      for (; ( tTestIterator != tTestQuery.end() ) ;tTestIterator++)
      {
        cout << *tTestIterator;
      }
    }
    _DropTestSchema ();
  }
  catch (const uesql::TExceptionUESQL_Sqlerror& rktEXCEPTION)
  {
    _DropTestSchema ();
    cerr << "SQLSTATE="    << uesql::SQLSTATE    << endl;
    cerr << "SQLCODE="     << uesql::SQLCODE     << endl;
    cerr << "DESCRIPTION=" << _GetErrorMessage() << endl;
    TEST_FAIL_WITH_CODE (uesql::SQLCODE);
  }
  catch (const mpcl::TBaseException& rktEXCEPTION)
  {
    _DropTestSchema ();
    cerr << rktEXCEPTION;
    TEST_FAIL_WITH_CODE (3);
  }  
  catch (...)
  {
    _DropTestSchema ();
    cerr << "Unhandled exception" << endl;
    TEST_FAIL_WITH_CODE (3);
  }
  if ( !TEST_IN_SILENT_MODE )
  {
    mpcl::log.erase (cerr);
  }
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // main()
