//
//  Name:      test-iterators.uesql.cc
//  Author:    Francisco Vides Fernandez
//  Summary:   
//  Date:      $Date: 2001/02/15 17:04:30 $
//  Revision:  $Revision: 1.8 $
//
//  Copyright (C) 1999  Rafael Jesus Alcantara Perez <rafa@dedalo-ing.com>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
//  MA 02111-1307, USA.
//

#include <iostream>
#include <mpcl/config_processor.hh>
#include <mpcl/general-exceptions.hh>
#include <mpcl/string.hh>
#include <mpcl/test.h>
#include <uesql/iterator.hh>
#include <uesql/query.hh>


using uesql::TSqlDataType;
using uesql::TSqlDate;
using uesql::TSqlInteger;
using uesql::TSqlReal;
using uesql::TSqlString;
using uesql::TIterator;
using uesql::TExceptionUESQL_Sqlerror;
using uesql::TQuery;

//
// L O C A L  C L A S S E S
//

class TTestInstance
{
    
  public:

    TSqlDate     tAttrib0;
    TSqlInteger  tAttrib1;
    TSqlReal     tAttrib2;
    TSqlString   tAttrib3;

    
  public:

    TTestInstance()  :
      tAttrib0() ,
      tAttrib1() ,
      tAttrib2() ,
      tAttrib3() {};


  public: 

    TSqlDataType& operator [] (unsigned int uiI)
    {
      switch (uiI)
      {
        case 0:
        {
          return tAttrib0;
          break;
        }
        case 1:
        {
          return tAttrib1;
          break;
        }
        case 2:
        {
          return tAttrib2;
          break;
        }
        case 3:
        {
          return tAttrib3;
          break;
        }
        default:        
        {
          throw mpcl::TExceptionEL_Constraint ("index out of range", __FILE__, __LINE__);
        }
      }
      return tAttrib0; // never reached
    }

    
    bool operator == (const TTestInstance& rktINSTANCE) const
    {
      return 
        ( tAttrib0 == rktINSTANCE.tAttrib0 ) &&
        ( tAttrib1 == rktINSTANCE.tAttrib1 ) &&
        ( tAttrib2 == rktINSTANCE.tAttrib2 ) &&
        ( tAttrib3 == rktINSTANCE.tAttrib3 ) ;
    }
    

};  // class TTestInstance


ostream& operator << (ostream& rtOSTREAM, TTestInstance& rtINSTANCE)
{

  for (register unsigned int I = 0; I < 4 ; I++)
  {
    rtOSTREAM << rtINSTANCE [I].get() << endl;
  }
  return rtOSTREAM;

}  // operator <<()


struct MQuery
{

  protected:

    
    void declare (uesql::TSqlString yCURSOR_NAME, std::size_t* ptTUPLE_COUNT) const
    {
      TSqlInteger   iAux;
      extern "UESQL::default"
      {
        select count(*) into :iAux from instance;
        declare :yCURSOR_NAME cursor for 
          select attrib0, attrib1, attrib2, attrib3  
            from instance;
      }
      *ptTUPLE_COUNT = (size_t) iAux;
    }

    void fetchNext (const uesql::TSqlString& rkyCURSOR_NAME, TTestInstance& tINSTANCE)
    {
      TTestInstance tRet;
      extern "UESQL::default"
      {
        fetch
          from :rkyCURSOR_NAME
          into :tINSTANCE.tAttrib0,
               :tINSTANCE.tAttrib1,
               :tINSTANCE.tAttrib2,
               :tINSTANCE.tAttrib3;
      }
    }

    TTestInstance& fetchAbsolute ( uesql::TSqlString yCURSOR_NAME        ,
                                   TTestInstance& tINSTANCE              ,
                                   const uesql::TSqlInteger& rkiPOSITION )
    {
      extern "UESQL::default"
      {
        fetch absolute :rkiPOSITION
          from :yCURSOR_NAME
          into :tINSTANCE.tAttrib0,
               :tINSTANCE.tAttrib1,
               :tINSTANCE.tAttrib2,
               :tINSTANCE.tAttrib3;
      }
    }


};  // class struct MQuery


typedef uesql::TQuery<TTestInstance, MQuery>  TTestQuery;


//
//  L O C A L   V A R I A B L E S
//

static uesql::TSqlstateDescriptor   _tSqlstateDescriptor;


//
//  L O C A L   F U N C T I O N S
//

/**
*  Construct error message from SQL status.
*  @return SQL status message.
*/

static mpcl::xstring _GetErrorMessage (void)
{

  using mpcl::xstring;

  return ( xstring (_tSqlstateDescriptor.getClass())    +
           ": "                                         +
           xstring (_tSqlstateDescriptor.getSubclass()) +
           " (" + uesql::SQLMESSAGE + ")"               );

}  // _GetErrorMessage()


static void _CreateTestSchema ( const mpcl::xstring& rkyDBMS_SERVER_NAME ,
                                const mpcl::xstring& rkyUSER_NAME        ,
                                const mpcl::xstring& rkyUSER_PASSWORD    )
{

  using uesql::ComposeSchemaLocation;
  using uesql::ComposeUserLogin;
  using uesql::Quote;

  mpcl::xstring   yDbmsSchemaLocation     = ComposeSchemaLocation ( rkyDBMS_SERVER_NAME ,
                                                                    rkyUSER_NAME        );
  mpcl::xstring   yDbmsTestSchemaLocation = ComposeSchemaLocation ( rkyDBMS_SERVER_NAME     ,
                                                                    "TEST_ITERATORS_SCHEMA" );
  mpcl::xstring   yDbmsUserLogin          = ComposeUserLogin (rkyUSER_NAME, rkyUSER_PASSWORD);

  TEST_WRITE_INFO ("DBMS-SCHEMA-LOCATION      = %s", yDbmsSchemaLocation.c_str());
  TEST_WRITE_INFO ("DBMS-USER-LOGIN           = %s", yDbmsUserLogin.c_str());
  TEST_WRITE_INFO ("DBMS-TEST-SCHEMA-LOCATION = %s", yDbmsTestSchemaLocation.c_str());
  extern "UESQL::default"
  {
    --
    --  Connects to default schema.
    --
    connect to :Quote (yDbmsSchemaLocation)
      user :Quote (yDbmsUserLogin);
    --
    --  Creates schema test_iterators_schema.
    --
    create schema test_iterators_schema
      create table instance
      (
        attrib0   date,
        attrib1   integer,
        attrib2   real,
        attrib3   varchar(20)
      );
    --
    --  Connects to the newly created schema.
    --
    connect to :Quote (yDbmsTestSchemaLocation)
      as 'myconnection'
      user :Quote (yDbmsUserLogin);
  }

}  // _CreateTestSchema()


static void _DropTestSchema (void)
{

  extern "UESQL::default"
  {
    --
    --  Removes tables.
    --
    drop table instance cascade;
    disconnect current;
    set connection default;
  
    --
    --  Removes schema test_iterators_schema.
    --
    drop schema test_iterators_schema cascade;
  }

}   // _DropTestSchema()


static void _FillTables (void)
{

  extern "UESQL::default"
  {
    insert into instance values ('20-12-2000', 0, 0.0, 'valor 0');
    insert into instance values ('20-12-2001', 1, 1.1, 'valor 1');
    insert into instance values ('20-12-2002', 2, 2.2, 'valor 2');
  }

}   // _FillTables()


static void _TestIteratorOperators (void)
{

  // Test ++I

  // Test I++

}   // _TestOperators()


int main (int argc, const char** argv)
{
  register int             I;
  mpcl::TConfigProcessor   tConfigProcessor (argc, argv);

  TEST_INIT ("Test for Cursor inside C++ Iterators");
  TEST_START_WATCH;
  try
  {
    tConfigProcessor.addOption ("dbms-server-name",   "o", getenv ("DBMS_SERVER_NAME"));
    tConfigProcessor.addOption ("dbms-user-name",     "u", getenv ("DBMS_USER_NAME"));
    tConfigProcessor.addOption ("dbms-user-password", "p", getenv ("DBMS_USER_NAME"));
    tConfigProcessor["dbms-server-name"].setUsageString ("Server where database resides");
    tConfigProcessor["dbms-user-name"].setUsageString ("");
    tConfigProcessor["dbms-user-password"].setUsageString ("");
    tConfigProcessor.processOptions();
    
    if ( !TEST_IN_SILENT_MODE )
    {
      mpcl::log.also (cerr);
    }
    extern "UESQL::default" 
    {
      --
      --  Whenever any SQLERROR condition throw an exception
      --
      whenever sqlerror throw TExceptionUESQL_Sqlerror;
      
    }
    _CreateTestSchema ( tConfigProcessor ["dbms-server-name"].value()   ,
                        tConfigProcessor ["dbms-user-name"].value()     ,
                        tConfigProcessor ["dbms-user-password"].value() );
    _FillTables();

    // <TODO comment="this will be the tests to run">
    _TestIteratorOperators ();
    // </TODO>    
    
    {
      // Iterate using a query
      TTestQuery             tTestQuery;
      TTestQuery::iterator   tTestIterator = tTestQuery.begin();

      // This one can test if an iterator's constructor returns a
      // valid one, being valid the data set
      if ( tTestIterator == tTestQuery.end() )
      {
        cout << "Alguna chorrada" << endl;
      }
      // Iterating a fixed number of times
      for (I = 0; I < 3 ;I++)
      {
        cout << *tTestIterator;
      }
      // Iterating through the container as usual
      tTestIterator = tTestQuery.begin();
      for (; ( tTestIterator != tTestQuery.end() ) ;tTestIterator++)
      {
        cout << *tTestIterator;
      }
    }
    _DropTestSchema ();
  }
  catch (const uesql::TExceptionUESQL_Sqlerror& rktEXCEPTION)
  {
    _DropTestSchema ();
    cerr << "SQLSTATE="    << uesql::SQLSTATE    << endl;
    cerr << "SQLCODE="     << uesql::SQLCODE     << endl;
    cerr << "DESCRIPTION=" << _GetErrorMessage() << endl;
    TEST_FAIL_WITH_CODE (uesql::SQLCODE);
  }
  catch (const mpcl::TBaseException& rktEXCEPTION)
  {
    _DropTestSchema ();
    cerr << rktEXCEPTION;
    TEST_FAIL_WITH_CODE (3);
  }  
  catch (...)
  {
    _DropTestSchema ();
    cerr << "Unhandled exception" << endl;
    TEST_FAIL_WITH_CODE (3);
  }
  if ( !TEST_IN_SILENT_MODE )
  {
    mpcl::log.erase (cerr);
  }
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // main()
